@@ -686,6 +686,7 @@ class Directory(collections.abc.Hashable,
                 collections.abc.Reversible,
                 collections.abc.Mapping,
                 collections.abc.Sized,
+                clu.abstract.Cloneable,
                 contextlib.AbstractContextManager,
                 os.PathLike,
                 metaclass=TypeLocker):
@@ -963,7 +964,7 @@ class Directory(collections.abc.Hashable,
         """ Sugar for calling os.walk(self.name)
             
             Note that the “followlinks” default here is True, whereas
-            the underlying functions default to False for that argument.
+            the underlying function defaults to False for that argument.
         """
         return os.walk(self.name, followlinks=followlinks)
     
@@ -1163,7 +1164,7 @@ class Directory(collections.abc.Hashable,
             dotpaths.extend(path_to_dotpath(os.path.join(root, filename),
                                             relative_to=self.name)
                             for filename in filenames)
-        return uniquify(sorted(dotpaths))
+        return sorted(uniquify(dotpaths))
     
     def suffix_histogram(self, subdir=None,
                                source=None,
@@ -1207,6 +1208,9 @@ class Directory(collections.abc.Hashable,
     def values(self):
         return OrderedValuesView(self)
     
+    def clone(self, deep=False, memo=None):
+        return self.directory(self.name)
+    
     def __repr__(self):
         return self.to_string()
     
